unregister<T extends Object> abstract method
Unregister an instance of an object or a factory/singleton by Type T or by name
instanceName if you need to dispose any resources you can do it using
disposingFunction function that provides an instance of your class to be disposed.
This function overrides the disposing you might have provided when registering.
Implementation
FutureOr unregister<T extends Object>({
Object? instance,
String? instanceName,
FutureOr Function(T)? disposingFunction,
});