areWaitedBy property
In case of a timeout while waiting for an instance to get ready This exception is thrown with information about who is still waiting.
If you pass the callee parameter to isReady, or define dependent Singletons
this maps lists which callees are waiting for whom.
Implementation
final Map<String, List<String>> areWaitedBy;